;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "ast-grep" "20250703.723"
  "Search code using ast-grep with completing-read interface."
  '((emacs "28.1"))
  :url "https://github.com/sunskyxh/ast-grep.el"
  :commit "3682f0cab0147e85d3f8ffc6b68b1dc30ffba5cd"
  :revdesc "3682f0cab014"
  :keywords '("tools" "matching")
  :authors '(("SunskyxXH" . "sunskyxh@gmail.com"))
  :maintainers '(("SunskyxXH" . "sunskyxh@gmail.com")))
